@@ -8,10 +8,15 @@ These tests can be run through the Nose testing framework.
 (c) 2010-2016 by Eric O. LEBIGOT (EOL).
 """
 
-
+from __future__ import division
+from __future__ import print_function
 
 
 # Standard modules
+from builtins import str
+from builtins import zip
+from builtins import map
+from builtins import range
 import copy
 import weakref
 import math
@@ -154,7 +159,7 @@ def compare_derivatives(func, numerical_derivatives,
                 args = []
                 for arg_num in range(num_args):
                     if arg_num in integer_arg_nums:
-                        args.append(random.choice(list(range(-10, 10))))
+                        args.append(random.choice(range(-10, 10)))
                     else:
                         args.append(
                             uncert_core.Variable(random.random()*4-2, 0))
@@ -214,7 +219,7 @@ def compare_derivatives(func, numerical_derivatives,
                                     % (funcname, err))
 
                 # Another argument might be forced to be an integer:
-                integer_arg_nums.add(random.choice(list(range(num_args))))
+                integer_arg_nums.add(random.choice(range(num_args)))
             else:
                 # We have found reasonable arguments, and the test passed:
                 break
@@ -337,15 +342,15 @@ def test_ufloat_fromstr():
         ## Pretty-print notation:
 
         # ± sign, global exponent (not pretty-printed):
-        '(3.141±0.001)E+02': (314.1, 0.1),
+        u'(3.141±0.001)E+02': (314.1, 0.1),
         # ± sign, individual exponent:
-        '3.141E+02±0.001e2': (314.1, 0.1),
+        u'3.141E+02±0.001e2': (314.1, 0.1),
 
         # ± sign, times symbol, superscript (= full pretty-print):
-        '(3.141 ± 0.001) × 10²': (314.1, 0.1),
+        u'(3.141 ± 0.001) × 10²': (314.1, 0.1),
 
         # NaN uncertainty:
-        '(3.141±nan)E+02': (314.1, float('nan')),
+        u'(3.141±nan)E+02': (314.1, float('nan')),
         '3.141e+02+/-nan': (314.1, float('nan')),
         '3.4(nan)e10': (3.4e10, float('nan')),
         # NaN value:
@@ -419,7 +424,7 @@ def test_fixed_derivatives_basic_funcs():
             # by definition, to AffineScalarFunc objects: we first map
             # possible scalar arguments (used for calculating
             # derivatives) to AffineScalarFunc objects:
-            lambda *args: func(*list(map(uncert_core.to_affine_scalar, args))))
+            lambda *args: func(*map(uncert_core.to_affine_scalar, args)))
         compare_derivatives(func, numerical_derivatives, [num_args])
 
     # Operators that take 1 value:
@@ -443,7 +448,7 @@ def test_copy():
     y = copy.copy(x)
     assert x != y
     assert not(x == y)
-    assert y in list(y.derivatives.keys())  # y must not copy the dependence on x
+    assert y in y.derivatives.keys()  # y must not copy the dependence on x
 
     z = copy.deepcopy(x)
     assert x != z
@@ -527,7 +532,7 @@ def test_pickling():
         # Unpickling test:
         x.new_attr = 'New attr value'
         x_unpickled = pickle.loads(pickle.dumps(x))
-        # Must exist (From the slots of the parent class):
+        # Must exist (from the slots of the parent class):
         x_unpickled.nominal_value
         x_unpickled.new_attr  # Must exist
 
@@ -1643,7 +1648,7 @@ def test_format():
             # found in Python 2.7: '{:.1%}'.format(0.0055) is '0.5%'.
             '.1u%': '(42.0+/-0.5)%',
             '.1u%S': '42.0(5)%',
-            '%P': '(42.0±0.5)%'
+            '%P': u'(42.0±0.5)%'
         },
 
         # Particle Data Group automatic convention, including limit cases:
@@ -1714,17 +1719,17 @@ def test_format():
         # instead of 1.4 for Python 3.1. The problem does not appear
         # with 1.2, so 1.2 is used.
         (-1.2e-12, 0): {
-            '12.2gPL': r'  -1.2×10⁻¹²±           0',
+            '12.2gPL': u'  -1.2×10⁻¹²±           0',
             # Pure "width" formats are not accepted by the % operator,
             # and only %-compatible formats are accepted, for Python <
             # 2.6:
             '13S': '  -1.2(0)e-12',
-            '10P': '-1.2×10⁻¹²±         0',
+            '10P': u'-1.2×10⁻¹²±         0',
             'L': r'\left(-1.2 \pm 0\right) \times 10^{-12}',
             # No factored exponent, LaTeX
             '1L': r'-1.2 \times 10^{-12} \pm 0',
             'SL': r'-1.2(0) \times 10^{-12}',
-            'SP': r'-1.2(0)×10⁻¹²'
+            'SP': u'-1.2(0)×10⁻¹²'
         },
 
         # Python 3.2 and 3.3 give 1.4e-12*1e+12 = 1.4000000000000001
@@ -1735,7 +1740,7 @@ def test_format():
             '15GS': '  -1.2(%s)E-12' % NaN_EFG,
             'SL': r'-1.2(\mathrm{nan}) \times 10^{-12}',  # LaTeX NaN
             # Pretty-print priority, but not for NaN:
-            'PSL': '-1.2(\mathrm{nan})×10⁻¹²',
+            'PSL': u'-1.2(\mathrm{nan})×10⁻¹²',
             'L': r'\left(-1.2 \pm \mathrm{nan}\right) \times 10^{-12}',
             # Uppercase NaN and LaTeX:
             '.1EL': (r'\left(-1.2 \pm \mathrm{%s}\right) \times 10^{-12}'
@@ -1746,8 +1751,8 @@ def test_format():
 
         (3.14e-10, 0.01e-10): {
             # Character (Unicode) strings:
-            'P': '(3.140±0.010)×10⁻¹⁰',  # PDG rules: 2 digits
-            'PL': r'(3.140±0.010)×10⁻¹⁰',  # Pretty-print has higher priority
+            u'P': u'(3.140±0.010)×10⁻¹⁰',  # PDG rules: 2 digits
+            u'PL': u'(3.140±0.010)×10⁻¹⁰',  # Pretty-print has higher priority
             # Truncated non-zero uncertainty:
             '.1e': '(3.1+/-0.0)e-10',
             '.1eS': '3.1(0.0)e-10'
@@ -1977,7 +1982,7 @@ def test_format():
             'S': '-inf(inf)',
             'LS': '-\infty(\infty)',
             'L': '-\infty \pm \infty',
-            'LP': '-\infty±\infty',
+            'LP': u'-\infty±\infty',
             # The following is consistent with Python's own
             # formatting, which depends on the version of Python:
             # formatting float("-inf") with format(..., "020") gives
@@ -2003,7 +2008,7 @@ def test_format():
             'S': 'nan(inf)',
             'LS': '\mathrm{nan}(\infty)',
             'L': '\mathrm{nan} \pm \infty',
-            'LP': '\mathrm{nan}±\infty'
+            'LP': u'\mathrm{nan}±\infty'
         },
 
         # Leading zeroes in the shorthand notation:
@@ -2111,8 +2116,8 @@ def test_unicode_format():
 
     x = ufloat(3.14159265358979, 0.25)
 
-    assert isinstance('Résultat = %s' % x.format(''), str)
-    assert isinstance('Résultat = %s' % x.format('P'), str)
+    assert isinstance(u'Résultat = %s' % x.format(''), str)
+    assert isinstance(u'Résultat = %s' % x.format('P'), str)
 
 ###############################################################################
 
